# react-native-osano-web

## Getting started like library

`$ npm install git+https://ussvc01.newsmemory.com:3000/tecnavia/react-native-osano-web --save`

## Getting Started standalone

Before integrating the `react-native-osano-web` package into your project, ensure you have the correct environment setup:

1. **Node.js and npm**: This package requires npm version 16. You can check your npm version by running `npm --version` in your terminal. If you need to switch versions, consider using a version manager like `nvm`. The required version can also be found in the `.nvmrc` file at the root of the project.

2. **Yarn Package Manager**: Install Yarn globally using npm by running:

```bash
npm install -g yarn
```

3. **Project Setup**: Once Yarn is installed, navigate to the root of your project and run:

```bash
yarn
```

This will install all dependencies specified in your project's `package.json` file.

4. **Example Project**: To run the example project included with the `react-native-osano-web` package:

    a. Navigate to the `example` directory:

    ```bash
    cd example
    ```

    b. Install dependencies:

    ```bash
    yarn
    ```

    c. Start the example project:

    ```bash
    yarn start
    ```

    d. To run the example app on Android or iOS, use:

    ```bash
    yarn android
    ```

    or

    ```bash
    yarn ios
    ```

    These commands will build and run the example app on the respective platform emulator or connected device.

Following these steps will set up your environment for developing with the `react-native-osano-web` package and running the example project.

## Usage

[see example App.js](./example/App.js)

Osano Container is a provider that display osano cmp over children
Display it when has the value, you could set value throught Osano.update

### Description

- **OsanoContainer**: A component that renders the Osano CMP UI over its children. It should encapsulate the part of your app where you need to manage consent.
- **Osano.update**: A method to configure the Osano CMP with your specific `customerId`, `projectId`, and `siteDomain`. These values are essential for the CMP to function correctly and should be obtained from your Osano account.

### Additional Methods

The integration also provides additional methods to further manage consent and compliance within your application:

- **askUspData**: This method returns an object containing the user's consent information related to the U.S. Privacy (USP) framework. It can be used to retrieve the current state of a user's consent under USP regulations. For more details on the USP API, refer to the [US Privacy API documentation](https://github.com/InteractiveAdvertisingBureau/USPrivacy/blob/master/CCPA/USP%20API.md).

- **askTcData**: Similar to `askUspData`, this method returns an object containing the user's consent information, but for the Transparency & Consent Framework (TCF). This is useful for applications operating within jurisdictions that adhere to the TCF guidelines. For more information on the TCF API, see the [TCF CMP API v2 documentation](https://github.com/InteractiveAdvertisingBureau/GDPR-Transparency-and-Consent-Framework/blob/master/TCFv2/IAB%20Tech%20Lab%20-%20CMP%20API%20v2.md).

- **show**: This method triggers the Osano CMP UI to be displayed, allowing the user to change their consent preferences. It can be invoked at any point in the application where you might need to prompt the user to review or alter their consent decisions.

### Example Usage

```javascript
// Retrieve USP consent data
const uspData = Osano.askUspData().then((uspData) => console.log(uspData));

// Retrieve TC consent data
Osano.askTcData().then((tcData) => console.log(tcData));

// Show the Osano consent UI to allow the user to change their consent preferences
Osano.show();
```
### Handling Consent

The `onConsent` callback in the `OsanoContainer` component is triggered when the user makes a consent decision. Use this callback to handle the consent result in your application, such as logging consent or adjusting application behavior based on user consent.

## Conclusion

Integrating Osano into your React Native application helps ensure compliance with privacy regulations by managing user consent for data collection and processing. Follow the steps outlined above to add Osano CMP to your application.
