import React, { useEffect, useState } from "react";
import { useSafeAreaInsets } from "react-native-safe-area-context";
import { OsanoUi } from "./osano-ui";
import OsanoContext from "./osano-context";
import { OsanoHook } from "./osano";
import { useCallbacks } from "./useCallbacks";
/**
 * Is a provider that will wrap the children and provide the configuration to the Osano component
 * setHook is used to update the configuration of the Context outside component lifecycle (is not a good practice)
 */
function OsanoContainer(props) {
  const {
    children,
    considerSafeArea = true,
    configuration: defaultConfiguration
  } = props;
  const [configuration, setConfiguration] = useState(defaultConfiguration);
  const safeAreaInsets = useSafeAreaInsets();
  const callbacks = useCallbacks(props);
  useEffect(() => {
    OsanoHook.setHook(setConfiguration);
  }, [setConfiguration]);
  const insets = considerSafeArea ? safeAreaInsets : {
    top: 0,
    right: 0,
    bottom: 0,
    left: 0
  };
  return /*#__PURE__*/React.createElement(OsanoContext.Provider, {
    value: configuration
  }, children, /*#__PURE__*/React.createElement(OsanoUi, {
    insets: insets,
    callbacks: callbacks
  }));
}
export default OsanoContainer;
//# sourceMappingURL=osano-container.js.map