/**
 * This namespace take a pending promises map
 * Expose methods to create, resolve and reject promises
 */
export let OsanoPromises;
(function (_OsanoPromises) {
  const TIMEOUT = 5000;
  const pendingPromises = _OsanoPromises.pendingPromises = {};
  const make = _OsanoPromises.make = (key, timeout, run) => {
    return new Promise((res, rej) => {
      pendingPromises[key] = {
        resolve: res,
        reject: rej
      };
      if (timeout) {
        setTimeout(() => reject(key, new Error(`Promise ${key} went in timeout`)), TIMEOUT);
      }
      run === null || run === void 0 || run();
    });
  };
  const resolve = _OsanoPromises.resolve = (promiseKey, data) => {
    const pendingPromise = pendingPromises[promiseKey];
    if (!pendingPromise) return;
    pendingPromise.resolve(data);
    pendingPromises[promiseKey] = undefined;
  };
  const reject = _OsanoPromises.reject = (promiseKey, error) => {
    const pendingPromise = pendingPromises[promiseKey];
    if (!pendingPromise) return;
    pendingPromise.reject(error);
    pendingPromises[promiseKey] = undefined;
  };
  const rejects = _OsanoPromises.rejects = error => {
    Object.keys(pendingPromises).forEach(key => {
      reject(key, error);
    });
  };
})(OsanoPromises || (OsanoPromises = {}));
//# sourceMappingURL=osano-promises.js.map