import { StyleSheet, View } from "react-native";
import { OsanoWebView } from "./osano-webview";
import React, { useCallback, useEffect, useRef } from "react";
import OsanoContext from "./osano-context";
import { OsanoWebViewUtils } from "./osano-webview-utils";
import { useJavascriptInjection } from "./useJavascriptInjection";
import { useMessage } from "./useMessage";
const styles = StyleSheet.create({
  hidden: {
    display: "none"
  },
  absolute: {
    backgroundColor: "rgba(0, 0, 0, 0.8)",
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  }
});
/**
 * Osano ui component handle if the webview is visible or not
 * Handle also events to communicate with the webview and also handle onMessage from the webview
 */
export const OsanoUi = props => {
  const {
    insets,
    callbacks
  } = props;
  const ref = useRef(null);
  const [hidden, setHidden, onMessage] = useMessage(callbacks);
  useEffect(() => {
    if (hidden) {
      var _callbacks$onClose;
      callbacks === null || callbacks === void 0 || (_callbacks$onClose = callbacks.onClose) === null || _callbacks$onClose === void 0 || _callbacks$onClose.call(callbacks);
    }
  }, [hidden, callbacks]);
  useJavascriptInjection(ref);

  /**
   * Handle the url otu of the webview, open other links in the browser
   */
  const onShouldStartLoadWithRequest = useCallback(event => {
    if (!(callbacks !== null && callbacks !== void 0 && callbacks.onLoadUrl)) return true;
    //TODO Reject active callback????
    return callbacks.onLoadUrl(event);
  }, [callbacks]);
  const hide = useCallback(() => setHidden(true), [setHidden]);
  const {
    top,
    bottom
  } = insets;
  return /*#__PURE__*/React.createElement(OsanoContext.Consumer, null, configuration => {
    if (!configuration) return null;
    return /*#__PURE__*/React.createElement(View, {
      style: hidden ? styles.hidden : [styles.absolute, {
        top,
        bottom
      }]
    }, /*#__PURE__*/React.createElement(OsanoWebView, {
      key: `${JSON.stringify(configuration)}`,
      ref: ref,
      source: {
        html: OsanoWebViewUtils.html(configuration),
        baseUrl: configuration.siteDomain
      },
      onMessage: onMessage,
      onError: hide,
      onHttpError: hide,
      onShouldStartLoadWithRequest: onShouldStartLoadWithRequest
    }));
  });
};
//# sourceMappingURL=osano-ui.js.map