export let OsanoWebViewUtils;
(function (_OsanoWebViewUtils) {
  const html = _OsanoWebViewUtils.html = configuration => {
    const {
      customerId,
      projectId,
      appVersion,
      vendorListUrl
    } = configuration;
    const vendorUrl = vendorListUrl ?? `/default_react_native.php?action=cmpVendorList&version=${appVersion}`;
    return /*javascript*/`
            <html>
                <head>
                    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
                    <script src="https://cmp.osano.com/${customerId}/${projectId}/osano.js"></script>
                    <title>Osano CMP</title>
                </head>
                <body>
                    <script>
                        window.Osano('onInitialized', (consent) => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: consent, message: 'onInitialized' }));
                        });
                        window.Osano('onCookieBlocked', (cookie) => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: cookie, message: 'onCookieBlocked' }));
                        });
                        window.Osano('onConsentNew', (consent) => {
                            localStorage.setItem('osanoConsentDate', new Date().toISOString());
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: consent, message: 'onConsentNew' }));
                        });
                        window.Osano('onConsentSaved', (consent) => {
                            localStorage.setItem('osanoConsentDate', new Date().toISOString());
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: consent, message: 'onConsentSaved' }));
                        });
                        window.Osano('onScriptBlocked', (src) => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: src, message: 'onScriptBlocked' }));
                        });
                        window.Osano('onIframeBlocked', (src) => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: src, message: 'onIframeBlocked' }));
                        });
                        window.Osano('onUiChanged', (component, stateChange) => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ data: { component, state: stateChange }, message: 'onUiChanged' }));
                        });
                        window.Osano('onStorage', () => {
                            window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onStorage' }));
                        });
                        
                        function askUspData() {
                            __uspapi('getUSPData', 1, (data, success) => {
                                if(!success) {
                                    window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onTcData', error: new Error('something went wrong') }));
                                    return;
                                }
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onUspData', data }));
                            });
                        };
                        function askTcData() {
                            __tcfapi('getTCData', 2, (data, success) => {
                                if(!success) {
                                    window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onTcData', error: new Error('something went wrong') }));
                                    return;
                                }
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onTcData', data }));
                            });
                        }

                        function askVendorListData() {
                            fetch('${vendorUrl}')
                                .then((response) => response.json())
                                .then((response) => {
                                    window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onVendorListData', data: response }));
                                })
                                .catch((error) => {
                                    window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onVendorListData', error }));
                                });
                        }

                        function askConsentData(){
                            try{
                                const data = {
                                    analytics: window.Osano.cm.analytics,
                                    cmpVersion: window.Osano.cm.cmpVersion,
                                    drawerOpen: window.Osano.cm.drawerOpen,
                                    dialogOpen: window.Osano.cm.dialogOpen,
                                    jurisdiction: window.Osano.cm.jurisdiction,
                                    locale: window.Osano.cm.locale,
                                    marketing: window.Osano.cm.marketing,
                                    mode: window.Osano.cm.mode,
                                    optOut: window.Osano.cm.optOut,
                                    personalization: window.Osano.cm.personalization
                                }
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onConsentData', data }));
                            } catch (error) {
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onConsentData', error }));
                            }
                        }

                        function showDrawer(){
                            try{
                                window.Osano.cm.showDrawer('osano-cm-dom-info-dialog-open');
                            } catch (error) {
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onError', error }));
                            }
                        }

                        function showDialog(){
                            try{
                                window.Osano.cm.showDialog('osano-cm-dom-info-dialog-open');
                            } catch (error) {
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onError', error }));
                            }
                        }

                        function changeConsent(){
                            try{
                                window.Osano.cm.showDrawer('osano-cm-dom-info-dialog-open');
                            } catch (error) {
                                window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onError', error }));
                            }
                        }

                        function clearConsent(){
                            localStorage.clear();
                        }
                        
                        function getConsentDate(){
                            window.ReactNativeWebView.postMessage(JSON.stringify({ message: 'onConsentDate', data: localStorage.getItem('osanoConsentDate') }));
                        }
                    </script>

                    <style>
                        .osano-cm-widget {
                            display: none  !important;
                        }
                        .osano-cm-dialog {
                            max-height: 100% !important;
                        }
                    </style>
                </body>
            </html>`;
  };
})(OsanoWebViewUtils || (OsanoWebViewUtils = {}));
//# sourceMappingURL=osano-webview-utils.js.map