import { useCallback, useRef } from "react";
import { OsanoPromises } from "./osano-promises";
export const useCallbacks = props => {
  const {
    onClose: defaultOnClose,
    onConsent: defaultOnConsent,
    onError: defaultOnError,
    onLoadUrl: defaultOnLoadUrl,
    onUspData: defaultOnUspData,
    onTcData: defaultOnTcData,
    onConsentDate: defaultOnConsentDate,
    onConsentData: defaultOnConsentData,
    onVendorList: defaultOnVendorList
  } = props;
  const lastConsent = useRef();
  const onConsent = useCallback(consent => {
    lastConsent.current = consent;
    OsanoPromises.resolve("askConsent", consent);
    defaultOnConsent === null || defaultOnConsent === void 0 || defaultOnConsent(consent);
  }, [defaultOnConsent]);
  const onTcData = useCallback(data => {
    OsanoPromises.resolve("tcData", data);
    defaultOnTcData === null || defaultOnTcData === void 0 || defaultOnTcData(data);
  }, [defaultOnTcData]);
  const onUspData = useCallback(data => {
    OsanoPromises.resolve("uspData", data);
    defaultOnUspData === null || defaultOnUspData === void 0 || defaultOnUspData(data);
  }, [defaultOnUspData]);
  const onConsentDate = useCallback(data => {
    OsanoPromises.resolve("getConsentDate", data);
    defaultOnConsentDate === null || defaultOnConsentDate === void 0 || defaultOnConsentDate(data);
  }, [defaultOnConsentDate]);
  const onConsentData = useCallback(data => {
    OsanoPromises.resolve("consentData", data);
    defaultOnConsentData === null || defaultOnConsentData === void 0 || defaultOnConsentData(data);
  }, [defaultOnConsentData]);
  const onVendorList = useCallback(data => {
    OsanoPromises.resolve("vendorListData", data);
    defaultOnVendorList === null || defaultOnVendorList === void 0 || defaultOnVendorList(data);
  }, [defaultOnVendorList]);
  const onClose = useCallback(() => {
    OsanoPromises.resolve("changeConsent", lastConsent.current);
    defaultOnClose === null || defaultOnClose === void 0 || defaultOnClose();
  }, [defaultOnClose]);
  const onError = useCallback(error => {
    OsanoPromises.rejects(error);
    defaultOnError === null || defaultOnError === void 0 || defaultOnError(error);
  }, [defaultOnError]);
  const onCookieBlocked = useCallback(cookie => onError === null || onError === void 0 ? void 0 : onError(new Error(`Cookie blocked: ${cookie}`)), [onError]);
  const onScriptBlocked = useCallback(src => onError === null || onError === void 0 ? void 0 : onError(new Error(`Script blocked: ${src}`)), [onError]);
  const onIframeBlocked = useCallback(src => onError === null || onError === void 0 ? void 0 : onError(new Error(`Iframe blocked: ${src}`)), [onError]);
  return {
    onClose,
    onConsent,
    onLoadUrl: defaultOnLoadUrl,
    onUspData,
    onTcData,
    onConsentDate,
    onError,
    onCookieBlocked,
    onScriptBlocked,
    onIframeBlocked,
    onConsentData,
    onVendorList
  };
};
//# sourceMappingURL=useCallbacks.js.map