import { useCallback, useState } from "react";
import { Utils } from "./utils";
export const useMessage = callbacks => {
  const [hidden, setHidden] = useState(true);
  const onMessage = useCallback(event => {
    try {
      if (!Utils.isDefined(callbacks)) return;
      const {
        message,
        data,
        error
      } = JSON.parse(event.nativeEvent.data);
      if (Utils.isDefined(error)) {
        var _callbacks$onError;
        callbacks === null || callbacks === void 0 || (_callbacks$onError = callbacks.onError) === null || _callbacks$onError === void 0 || _callbacks$onError.call(callbacks, error);
        return;
      }
      if (message === "onInitialized") {
        // no-op, missing documentation
        return;
      }
      if (message === "onStorage") {
        var _callbacks$onStorage;
        callbacks === null || callbacks === void 0 || (_callbacks$onStorage = callbacks.onStorage) === null || _callbacks$onStorage === void 0 || _callbacks$onStorage.call(callbacks);
        return;
      }
      if (!Utils.isDefined(data)) {
        var _callbacks$onError2;
        callbacks === null || callbacks === void 0 || (_callbacks$onError2 = callbacks.onError) === null || _callbacks$onError2 === void 0 || _callbacks$onError2.call(callbacks, new Error("Data is missing"));
        return;
      }
      if (message === "onConsentNew" || message === "onConsentSaved") {
        var _callbacks$onConsent;
        callbacks === null || callbacks === void 0 || (_callbacks$onConsent = callbacks.onConsent) === null || _callbacks$onConsent === void 0 || _callbacks$onConsent.call(callbacks, data);
      } else if (message === "onUiChanged") {
        var _callbacks$onUiChange;
        // We don't want to show the widget, the drawer should be opened from app settings
        if (data.component === "widget") return;
        callbacks === null || callbacks === void 0 || (_callbacks$onUiChange = callbacks.onUiChanged) === null || _callbacks$onUiChange === void 0 || _callbacks$onUiChange.call(callbacks, data.component, data.state);
        setHidden(data.state === "hide");
      } else if (message === "onCookieBlocked") {
        var _callbacks$onCookieBl;
        callbacks === null || callbacks === void 0 || (_callbacks$onCookieBl = callbacks.onCookieBlocked) === null || _callbacks$onCookieBl === void 0 || _callbacks$onCookieBl.call(callbacks, data);
      } else if (message === "onScriptBlocked") {
        var _callbacks$onScriptBl;
        callbacks === null || callbacks === void 0 || (_callbacks$onScriptBl = callbacks.onScriptBlocked) === null || _callbacks$onScriptBl === void 0 || _callbacks$onScriptBl.call(callbacks, data);
      } else if (message === "onIframeBlocked") {
        var _callbacks$onIframeBl;
        callbacks === null || callbacks === void 0 || (_callbacks$onIframeBl = callbacks.onIframeBlocked) === null || _callbacks$onIframeBl === void 0 || _callbacks$onIframeBl.call(callbacks, data);
      } else if (message === "onTcData") {
        var _callbacks$onTcData;
        callbacks === null || callbacks === void 0 || (_callbacks$onTcData = callbacks.onTcData) === null || _callbacks$onTcData === void 0 || _callbacks$onTcData.call(callbacks, data);
      } else if (message === "onUspData") {
        var _callbacks$onUspData;
        callbacks === null || callbacks === void 0 || (_callbacks$onUspData = callbacks.onUspData) === null || _callbacks$onUspData === void 0 || _callbacks$onUspData.call(callbacks, data);
      } else if (message === "onConsentDate") {
        var _callbacks$onConsentD;
        callbacks === null || callbacks === void 0 || (_callbacks$onConsentD = callbacks.onConsentDate) === null || _callbacks$onConsentD === void 0 || _callbacks$onConsentD.call(callbacks, data);
      } else if (message === "onVendorListData") {
        var _callbacks$onVendorLi;
        callbacks === null || callbacks === void 0 || (_callbacks$onVendorLi = callbacks.onVendorList) === null || _callbacks$onVendorLi === void 0 || _callbacks$onVendorLi.call(callbacks, data);
      } else if (message === "onConsentData") {
        var _callbacks$onConsentD2;
        callbacks === null || callbacks === void 0 || (_callbacks$onConsentD2 = callbacks.onConsentData) === null || _callbacks$onConsentD2 === void 0 || _callbacks$onConsentD2.call(callbacks, data);
      }
    } catch (error) {
      var _callbacks$onError3;
      callbacks === null || callbacks === void 0 || (_callbacks$onError3 = callbacks.onError) === null || _callbacks$onError3 === void 0 || _callbacks$onError3.call(callbacks, error);
    }
  }, [callbacks]);
  return [hidden, setHidden, onMessage];
};
//# sourceMappingURL=useMessage.js.map