import { IConsent, IConsentData, ITcData, IUspData, IVendorList } from "./types";
/**
 * This namespace take a pending promises map
 * Expose methods to create, resolve and reject promises
 */
export declare namespace OsanoPromises {
    type PromiseData = {
        tcData: ITcData | undefined;
        uspData: IUspData | undefined;
        askConsent: IConsent | undefined;
        changeConsent: IConsent | undefined;
        getConsentDate: string | undefined;
        vendorListData: IVendorList | undefined;
        consentData: IConsentData | undefined;
    };
    type PromiseKeys = keyof PromiseData;
    type IPending<K extends PromiseKeys> = {
        resolve: (data: PromiseData[K]) => void;
        reject: (error: Error) => void;
    };
    export const pendingPromises: {
        [K in PromiseKeys]?: IPending<K>;
    };
    /**
     * Make a generic promise and save it in the pendingPromises object
     * If exists a run function, it will be executed
     * @param {timeout} used to reject the promise after TIMEOUT, set false when the method needs an user interaction
     */
    export const make: <K extends keyof PromiseData>(key: K, timeout: boolean, run?: () => void) => Promise<PromiseData[K]>;
    /**
     * This method is used to resolve a pending promise with the given data
     * The promise is identified by the key
     */
    export const resolve: <K extends keyof PromiseData>(promiseKey: K, data: PromiseData[K]) => void;
    /**
     * This method is used to reject a pending promise with the error
     * The promise is identified by the key
     */
    export const reject: <K extends keyof PromiseData>(promiseKey: K, error: Error) => void;
    /**
     * This method is used to reject all the pending promises with the given error
     */
    export const rejects: (error: Error) => void;
    export {};
}
//# sourceMappingURL=osano-promises.d.ts.map