import { IConfiguration, IVendorList } from "./types";
export declare namespace OsanoHook {
    const consumeConfiguration: () => void;
    const setHook: (cb: React.Dispatch<React.SetStateAction<IConfiguration | undefined>>) => void;
}
/**
 * This interface is used to interact with the Osano component
 * You should add only methods that you want to expose outside of the library
 */
export declare namespace Osano {
    /**
     * This method save the promise and trigger the event, see osano-ui.tsx
     * The promise will be resolved when the webview will send the data to the app
     */
    const askTcData: () => Promise<import("./types").ITcData | undefined>;
    /**
     * This method save the promise and trigger the event, see osano-ui.tsx
     * The promise will be resolved when the webview will send the data to the app
     */
    const askUspData: () => Promise<import("./types").IUspData | undefined>;
    /**
     * This method save the promise and trigger the event to retrieve the consent data
     * Osano doesn't provide a method to retrieve the consent data,
     * So at the moment we are using an internal APi
     */
    const askConsentData: () => Promise<import("./types").IConsentData | undefined>;
    /**
     * This method save the promise and trigger the event to retrieve the vendor list
     */
    const askVendorListData: () => Promise<IVendorList | undefined>;
    /**
     * You could use this method to ask the user for consent and await the result
     * If osano already asked the <user for consent, the promise will be resolved immediately
     */
    const ask: (configuration: IConfiguration) => Promise<import("./types").IConsent | undefined>;
    /**
     * Destroy view, use it if you are restarting the app without make a full reload (The container still exists)
     */
    const destroy: () => void;
    const updateData: () => Promise<[import("./types").ITcData | undefined, import("./types").IUspData | undefined]>;
    /**
     * This method trigger the event to show the drawer
     * The promise will be resolved when the user will close the drawer
     * If nothing change, the promise will be resolved with the last consent
     */
    const change: () => Promise<import("./types").IConsent | undefined>;
    /**
     * This method trigger the event to show the drawer
     * Doesn't return anything
     */
    const showDrawer: () => void;
    /**
     * This method trigger the event to show the drawer
     * Doesn't return anything
     */
    const showDialog: () => void;
    /**
     * This method trigger the clear of the local storage
     * Doesn't return anything
     */
    const clear: () => Promise<void>;
    /**
     * This method trigger the event to get the consent date
     */
    const getConsentDate: () => Promise<string | undefined>;
}
//# sourceMappingURL=osano.d.ts.map