export type ITcData = Record<string, number | string>;
export type IUspData = Record<string, number | string>;
export interface IConfiguration {
    /**
     * Url of the vendor list, it is used to fetch the vendor list
     */
    vendorListUrl?: string;
    /**
     * Version of the app, used to fetch vendor list
     */
    appVersion: string;
    /**
     * Main identifier of the customer, see script tag that Osano provides for integration, is the first string hash
     */
    customerId: string;
    /**
     * Project identifier, see script tag that Osano provides for integration, is the second string hash
     */
    projectId: string;
    /**
     * The name of domain, it is used like baseUrl in the webview, it is used by osano to store cookies
     */
    siteDomain: string;
    /**
     * All consents given before the reset date must be deleted.
     */
    resetConsentDate: string;
}
/**
 * Widget is a small button that appears on the bottom right of the screen
 * Drawer is a full screen dialog that appears from the right of the screen
 */
export type IDialog = "drawer" | "widget";
export type IDialogStatus = "hide" | "show";
export type IConsentResult = "ACCEPT" | "DENY";
export type IConsentCategories = "ANALYTICS" | "MARKETING" | "PERSONALIZATION" | "ESSENTIAL" | "OPT-OUT" | "STORAGE";
export interface IInsets {
    top: number;
    right: number;
    bottom: number;
    left: number;
}
export type IConsent = {
    [key in IConsentCategories]: IConsentResult;
};
type IPurpose = {
    id: number;
    name: string;
    description: string;
    illustrations: string[];
};
export type IVendorList = {
    gvlSpecificationVersion: number;
    vendorListVersion: number;
    tcfPolicyVersion: number;
    lastUpdated: string;
    purposes: {
        [key: string]: IPurpose;
    };
    specialPurposes: {
        [key: string]: IPurpose;
    };
    features: {
        [key: string]: IPurpose;
    };
    specialFeatures: {
        [key: string]: IPurpose;
    };
    stacks: {
        [key: string]: {
            id: 1;
            purposes: number[];
            specialFeatures: number[];
            name: string;
            description: string;
        };
    };
};
/**
 * See https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#properties
 */
export type IConsentData = {
    analytics: boolean;
    cmpVersion: string;
    drawerOpen: boolean;
    dialogOpen: boolean;
    jurisdiction: string;
    locale: string;
    marketing: boolean;
    mode: "debug" | "permissive" | "production";
    optOut: boolean;
    personalization: boolean;
};
interface IMessage<T> {
    error?: Error;
    data: T | undefined;
}
export interface IMessageUi extends IMessage<{
    component: IDialog;
    state: IDialogStatus;
}> {
    message: "onUiChanged";
}
export interface IMessageConsent extends IMessage<IConsent> {
    message: "onInitialized" | "onConsentNew" | "onConsentSaved";
}
export interface IMessageStorage extends IMessage<undefined> {
    message: "onStorage";
}
export interface IMessageCookieBlocked extends IMessage<string> {
    message: "onCookieBlocked";
}
export interface IMessageScriptBlocked extends IMessage<string> {
    message: "onScriptBlocked";
}
export interface IMessageIframeBlocked extends IMessage<string> {
    message: "onIframeBlocked";
}
export interface IMessageTcfData extends IMessage<ITcData> {
    message: "onTcData";
}
export interface IMessageUspData extends IMessage<IUspData> {
    message: "onUspData";
}
export interface IMessageConsentDate extends IMessage<string> {
    message: "onConsentDate";
}
export interface IMessageVendorList extends IMessage<IVendorList> {
    message: "onVendorListData";
}
export interface IMessageConsentData extends IMessage<IConsentData> {
    message: "onConsentData";
}
export type IMessages = IMessageConsent | IMessageUi | IMessageStorage | IMessageCookieBlocked | IMessageScriptBlocked | IMessageIframeBlocked | IMessageTcfData | IMessageUspData | IMessageConsentDate | IMessageVendorList | IMessageConsentData;
export {};
//# sourceMappingURL=types.d.ts.map