/// <reference types="react" />
import { WebViewMessageEvent } from "react-native-webview";
import { IConsent, IConsentData, IDialog, IDialogStatus, ITcData, IUspData, IVendorList } from "./types";
import { ShouldStartLoadRequest } from "react-native-webview/lib/WebViewTypes";
export type IMessageCallbacks = {
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-consent-new
     */
    onConsent?: (consent: IConsent) => void;
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-ui-changed
     */
    onUiChanged?: (component: IDialog, state: IDialogStatus) => void;
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-storage
     */
    onStorage?: () => void;
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-cookie-blocked
     */
    onCookieBlocked?: (cookie: string) => void;
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-script-blocked
     */
    onScriptBlocked?: (src: string) => void;
    /**
     * https://developers.osano.com/cmp/javascript-api/developer-documentation-consent-javascript-api#events-iframe-blocked
     */
    onIframeBlocked?: (src: string) => void;
    /**
     * Callback when the UI is closed
     */
    onClose?: () => void;
    /**
     * OnMessage with TcData
     */
    onTcData?: (data: ITcData) => void;
    /**
     * OnMessage with UspData
     */
    onUspData?: (data: IUspData) => void;
    /**
     * Return consent date
     */
    onConsentDate?: (data: string) => void;
    /**
     * Called when the webview try to load something after a navigation event
     */
    onLoadUrl?: (event: ShouldStartLoadRequest) => boolean;
    /**
     * Generic on error message
     */
    onError?: (error: Error) => void;
    /**
     * OnMessage with VendorList
     */
    onVendorList?: (data: IVendorList) => void;
    /**
     * OnMessage with ConsentData
     */
    onConsentData?: (data: IConsentData) => void;
};
type IReturn = [boolean, React.Dispatch<React.SetStateAction<boolean>>, (event: WebViewMessageEvent) => void];
export declare const useMessage: (callbacks: IMessageCallbacks | undefined) => IReturn;
export {};
//# sourceMappingURL=useMessage.d.ts.map